@@ -842,7 +842,7 @@ class LkeClient(AbstractClient):
             opts: Dict = None,
     ) -> models.ExportAttributeLabelResponse:
         """
-        导出属性标签
+        导出标签
         """
         
         kwargs = {}
@@ -1437,7 +1437,7 @@ class LkeClient(AbstractClient):
             opts: Dict = None,
     ) -> models.ListSelectDocResponse:
         """
-        文档生成问答时，可通过该接口获得当前支持生成问答的文档列表，当前不支持xlsx、xls、csv格式的文档生成问答，且文档需处于待发布或已发布状态才可生成问答。
+        获取文档下拉列表。
         """
         
         kwargs = {}
@@ -1911,6 +1911,9 @@ class LkeClient(AbstractClient):
     ) -> models.VerifyQAResponse:
         """
         校验问答
+        知识库相关背景知识介绍
+        “知识库检索范围”文档：https://cloud.tencent.com/document/product/1759/112704
+        “标签”文档：https://cloud.tencent.com/document/product/1759/112956
         """
         
         kwargs = {}
